==> guard-1.2.4-sources.jar: cn/authing/guard/feedback/GoFeedbackButton.java <==
package cn.authing.guard.feedback;

import android.content.Context;
import android.content.Intent;
import android.util.AttributeSet;

import androidx.annotation.NonNull;
import androidx.annotation.Nullable;

import cn.authing.guard.R;
import cn.authing.guard.activity.AuthActivity;
import cn.authing.guard.activity.FeedbackActivity;
import cn.authing.guard.analyze.Analyzer;
import cn.authing.guard.flow.AuthFlow;
import cn.authing.guard.internal.GoSomewhereButton;

public class GoFeedbackButton extends GoSomewhereButton {

    public GoFeedbackButton(@NonNull Context context) {
        this(context, null);
    }

    public GoFeedbackButton(@NonNull Context context, @Nullable AttributeSet attrs) {
        this(context, attrs, R.attr.buttonStyle);
    }

    public GoFeedbackButton(@NonNull Context context, @Nullable AttributeSet attrs, int defStyleAttr) {
        super(context, attrs, defStyleAttr);
        Analyzer.report("GoHelpButton");

        setOnClickListener((v)->{
            if (context instanceof AuthActivity) {
                AuthActivity activity = (AuthActivity)context;
                AuthFlow flow = (AuthFlow) activity.getIntent().getSerializableExtra(AuthActivity.AUTH_FLOW);
                Intent intent = new Intent(getContext(), FeedbackActivity.class);
                intent.putExtra(AuthActivity.AUTH_FLOW, flow);
                intent.putExtra(AuthActivity.CONTENT_LAYOUT_ID, flow.getAuthHelpLayoutId());
                activity.startActivity(intent);
            }
        });
    }

    @Override
    protected String getDefaultText() {
        return getResources().getString(R.string.authing_feedback);
    }
}

==> guard-1.5.2-sources.jar: cn/authing/guard/feedback/GoFeedbackButton.java <==
package cn.authing.guard.feedback;

import android.content.Context;
import android.content.Intent;
import android.util.AttributeSet;

import androidx.annotation.NonNull;
import androidx.annotation.Nullable;

import cn.authing.guard.R;
import cn.authing.guard.activity.AuthActivity;
import cn.authing.guard.activity.FeedbackActivity;
import cn.authing.guard.analyze.Analyzer;
import cn.authing.guard.flow.AuthFlow;
import cn.authing.guard.internal.GoSomewhereButton;

public class GoFeedbackButton extends GoSomewhereButton {

    public GoFeedbackButton(@NonNull Context context) {
        this(context, null);
    }

    public GoFeedbackButton(@NonNull Context context, @Nullable AttributeSet attrs) {
        this(context, attrs, 0);
    }

    public GoFeedbackButton(@NonNull Context context, @Nullable AttributeSet attrs, int defStyleAttr) {
        super(context, attrs, defStyleAttr);
        Analyzer.report("GoHelpButton");

        setOnClickListener((v)->{
            if (context instanceof AuthActivity) {
                AuthActivity activity = (AuthActivity)context;
                AuthFlow flow = (AuthFlow) activity.getIntent().getSerializableExtra(AuthActivity.AUTH_FLOW);
                Intent intent = new Intent(getContext(), FeedbackActivity.class);
                intent.putExtra(AuthActivity.AUTH_FLOW, flow);
                intent.putExtra(AuthActivity.CONTENT_LAYOUT_ID, flow.getAuthHelpLayoutId());
                activity.startActivity(intent);
            }
        });
    }

    @Override
    protected String getDefaultText() {
        return getResources().getString(R.string.authing_feedback);
    }
}
